/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * xzggbal.h
 *
 * Code generation for function 'xzggbal'
 *
 */

#ifndef XZGGBAL_H
#define XZGGBAL_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "MAVEfast_types.h"

/* Function Declarations */
extern void xzggbal(emxArray_creal_T *A, int *ilo, int *ihi, emxArray_int32_T
                    *rscale);

#endif

/* End of code generation (xzggbal.h) */
